@@ -14,7 +14,7 @@ from pymobiledevice3.cli.companion_proxy import cli as companion_cli
 from pymobiledevice3.cli.crash import cli as crash_cli
 from pymobiledevice3.cli.developer import cli as developer_cli
 from pymobiledevice3.cli.diagnostics import cli as diagnostics_cli
-from pymobiledevice3.cli.list_devices import cli as list_devices_cli
+from pymobiledevice3.cli.usbmux import cli as usbmux_cli
 from pymobiledevice3.cli.lockdown import cli as lockdown_cli
 from pymobiledevice3.cli.mounter import cli as mounter_cli
 from pymobiledevice3.cli.notification import cli as notification_cli
@@ -47,7 +47,7 @@ logger = logging.getLogger(__name__)
 def cli():
     cli_commands = click.CommandCollection(sources=[
         developer_cli, mounter_cli, apps_cli, profile_cli, lockdown_cli, diagnostics_cli, syslog_cli, pcap_cli,
-        crash_cli, afc_cli, ps_cli, notification_cli, list_devices_cli, power_assertion_cli, springboard_cli,
+        crash_cli, afc_cli, ps_cli, notification_cli, usbmux_cli, power_assertion_cli, springboard_cli,
         provision_cli, backup_cli, restore_cli, activation_cli, companion_cli, webinspector_cli, amfi_cli
     ])
     cli_commands.context_settings = dict(help_option_names=['-h', '--help'])
