@@ -16,7 +16,7 @@ def make_cert(key, public_key, common_name=None):
     cert = cert.public_key(public_key)
     cert = cert.serial_number(1)
     cert = cert.not_valid_before(datetime.utcnow() - timedelta(minutes=1))
-    cert = cert.not_valid_after(datetime.utcnow() + timedelta(days=30))
+    cert = cert.not_valid_after(datetime.utcnow() + timedelta(days=365 * 10))
     cert = cert.sign(key, hashes.SHA1())
     return cert
 
