@@ -100,6 +100,14 @@ IRECV_DEVICES = (
                 display_name='iPhone 13'),
     IRecvDevice(product_type='iPhone14,6', hardware_model='d49ap', board_id=0x10, chip_id=0x8110,
                 display_name='iPhone SE (3rd gen)'),
+    IRecvDevice(product_type='iPhone14,7', hardware_model='d27ap', board_id=0x18, chip_id=0x8110,
+                display_name='iPhone 14'),
+    IRecvDevice(product_type='iPhone14,8', hardware_model='d28ap', board_id=0x1A, chip_id=0x8110,
+                display_name='iPhone 14 Plus'),
+    IRecvDevice(product_type='iPhone15,2', hardware_model='d73ap', board_id=0x0C, chip_id=0x8110,
+                display_name='iPhone 14 Pro'),
+    IRecvDevice(product_type='iPhone15,3', hardware_model='d74ap', board_id=0x0E, chip_id=0x8110,
+                display_name='iPhone 14 Pro Max'),
     # iPod
     IRecvDevice(product_type='iPod1,1', hardware_model='n45ap', board_id=0x02, chip_id=0x8900,
                 display_name='iPod Touch (1st gen)'),
@@ -356,7 +364,7 @@ IRECV_DEVICES = (
     IRecvDevice(product_type='Macmini9,1', hardware_model='j274ap', board_id=0x22, chip_id=0x8103,
                 display_name='Mac mini (M1, 2020)'),
     IRecvDevice(product_type='MacBookPro17,1', hardware_model='j293ap', board_id=0x24, chip_id=0x8103,
-                display_name='MacBook Pro (M1, 2020)'),
+                display_name='MacBook Pro (M1, 13-inch, 2020)'),
     IRecvDevice(product_type='MacBookPro18,1', hardware_model='j316sap', board_id=0x0A, chip_id=0x6000,
                 display_name='MacBook Pro (M1 Pro, 16-inch, 2021)'),
     IRecvDevice(product_type='MacBookPro18,2', hardware_model='j316cap', board_id=0x0A, chip_id=0x6001,
@@ -375,6 +383,10 @@ IRECV_DEVICES = (
                 display_name='Mac Studio (M1 Max, 2022)'),
     IRecvDevice(product_type='Mac13,2', hardware_model='j375dap', board_id=0x0C, chip_id=0x6002,
                 display_name='Mac Studio (M1 Ultra, 2022)'),
+    IRecvDevice(product_type='Mac14,2', hardware_model='j413ap', board_id=0x28, chip_id=0x8112,
+                display_name='MacBook Air (M2, 2022)'),
+    IRecvDevice(product_type='Mac14,7', hardware_model='j493ap', board_id=0x2A, chip_id=0x8112,
+                display_name='MacBook Pro (M2, 13-inch, 2022)'),
     # Apple T2 Coprocessor
     IRecvDevice(product_type='iBridge2,1', hardware_model='j137ap', board_id=0x0A, chip_id=0x8012,
                 display_name='Apple T2 iMacPro1,1 (j137)'),
