@@ -11,28 +11,37 @@ def img4_get_component_tag(compname):
         'ACIBT': b'acib',
         'ACIBTLPEM': b'lpbt',
         'ACIWIFI': b'aciw',
-        'Alamo': b'almo',
         'ANE': b'anef',
         'ANS': b'ansf',
         'AOP': b'aopf',
+        'AVE': b'avef',
+        'Alamo': b'almo',
+        'Ap,ANE1': b'ane1',
+        'Ap,ANE2': b'ane2',
+        'Ap,ANE3': b'ane3',
         'Ap,AudioAccessibilityBootChime': b'auac',
         'Ap,AudioBootChime': b'aubt',
         'Ap,AudioPowerAttachChime': b'aupr',
+        'Ap,BootabilityBrainTrustCache': b'trbb',
         'Ap,CIO': b'ciof',
         'Ap,HapticAssets': b'hpas',
         'Ap,LocalBoot': b'lobo',
         'Ap,LocalPolicy': b'lpol',
         'Ap,NextStageIM4MHash': b'nsih',
         'Ap,RecoveryOSPolicyNonceHash': b'ronh',
+        'Ap,RestoreANE1': b'ran1',
+        'Ap,RestoreANE2': b'ran2',
+        'Ap,RestoreANE3': b'ran3',
         'Ap,RestoreCIO': b'rcio',
         'Ap,RestoreTMU': b'rtmu',
         'Ap,Scorpius': b'scpf',
         'Ap,SystemVolumeCanonicalMetadata': b'msys',
         'Ap,TMU': b'tmuf',
         'Ap,VolumeUUID': b'vuid',
+        'Ap,rOSLogo1': b'rlg1',
+        'Ap,rOSLogo2': b'rlg2',
         'AppleLogo': b'logo',
         'AudioCodecFirmware': b'acfw',
-        'AVE': b'avef',
         'BatteryCharging': b'glyC',
         'BatteryCharging0': b'chg0',
         'BatteryCharging1': b'chg1',
@@ -41,28 +50,22 @@ def img4_get_component_tag(compname):
         'BatteryLow1': b'bat1',
         'BatteryPlugin': b'glyP',
         'CFELoader': b'cfel',
-        'Dali': b'dali',
+        'CrownFirmware': b'crwn',
         'DCP': b'dcpf',
+        'Dali': b'dali',
         'DeviceTree': b'dtre',
         'Diags': b'diag',
         'EngineeringTrustCache': b'dtrs',
         'ExtDCP': b'edcp',
-        'ftap': b'ftap',
-        'ftsp': b'ftsp',
         'GFX': b'gfxf',
         'Hamm': b'hamf',
         'Homer': b'homr',
-        'iBEC': b'ibec',
-        'iBoot': b'ibot',
-        'iBootData': b'ibdt',
-        'iBootTest': b'itst',
-        'iBSS': b'ibss',
-        'InputDevice': b'ipdf',
         'ISP': b'ispf',
+        'InputDevice': b'ipdf',
         'KernelCache': b'krnl',
+        'LLB': b'illb',
         'LeapHaptics': b'lphp',
         'Liquid': b'liqd',
-        'LLB': b'illb',
         'LoadableTrustCache': b'ltrs',
         'LowPowerWallet0': b'lpw0',
         'LowPowerWallet1': b'lpw1',
@@ -73,12 +76,13 @@ def img4_get_component_tag(compname):
         'NeedService': b'nsrv',
         'OS': b'OS\0\0',
         'OSRamdisk': b'osrd',
-        'PersonalizedDMG': b'pdmg',
         'PEHammer': b'hmmr',
         'PERTOS': b'pert',
         'PHLEET': b'phlt',
         'PMP': b'pmpf',
+        'PersonalizedDMG': b'pdmg',
         'RBM': b'rmbt',
+        'RTP': b'rtpf',
         'Rap,SoftwareBinaryDsp1': b'sbd1',
         'Rap,RTKitOS': b'rkos',
         'Rap,RestoreRTKitOS': b'rrko',
@@ -89,12 +93,10 @@ def img4_get_component_tag(compname):
         'RestoreExtDCP': b'recp',
         'RestoreKernelCache': b'rkrn',
         'RestoreLogo': b'rlgo',
+        'RestoreRTP': b'rrtp',
         'RestoreRamDisk': b'rdsk',
         'RestoreSEP': b'rsep',
         'RestoreTrustCache': b'rtsc',
-        'rfta': b'rfta',
-        'rfts': b'rfts',
-        'RTP': b'rtpf',
         'SCE': b'scef',
         'SCE1Firmware': b'sc1f',
         'SEP': b'sepi',
@@ -103,6 +105,16 @@ def img4_get_component_tag(compname):
         'SystemLocker': b'lckr',
         'SystemVolume': b'isys',
         'WCHFirmwareUpdater': b'wchf',
+        'ftap': b'ftap',
+        'ftsp': b'ftsp',
+        'iBEC': b'ibec',
+        'iBSS': b'ibss',
+        'iBoot': b'ibot',
+        'iBootData': b'ibdt',
+        'iBootDataStage1': b'ibd1',
+        'iBootTest': b'itst',
+        'rfta': b'rfta',
+        'rfts': b'rfts',
     }
 
     return component_tags.get(compname)
