@@ -208,7 +208,7 @@ class Recovery(BaseRestore):
         self.build_identity.populate_tss_request_parameters(parameters)
 
         # create basic request
-        # Adds @BBTicket, @HostPlatformInfo, @VersionInfo, @UUID
+        # Adds @HostPlatformInfo, @VersionInfo, @UUID
         request = TSSRequest()
 
         # add common tags from manifest
@@ -441,7 +441,7 @@ class Recovery(BaseRestore):
             self.logger.info('going into Recovery')
 
             # in case lockdown has disconnected while waiting for a ticket
-            self.device.lockdown = LockdownClient(udid=self.device.lockdown.udid)
+            self.device.lockdown = LockdownClient(serial=self.device.lockdown.udid)
             self.device.lockdown.enter_recovery()
 
             self.device.lockdown = None
