@@ -633,7 +633,7 @@ class Restore(BaseRestore):
 
         while True:
             try:
-                client = ServiceConnection.create(self._restored.udid, data_port)
+                client = ServiceConnection.create_using_usbmux(self._restored.udid, data_port)
                 break
             except ConnectionFailedError:
                 self.logger.debug('Retrying connection...')
@@ -1149,7 +1149,7 @@ class Restore(BaseRestore):
 
         while True:
             try:
-                client = ServiceConnection.create(self._restored.udid, data_port)
+                client = ServiceConnection.create_using_usbmux(self._restored.udid, data_port)
                 break
             except ConnectionFailedError:
                 self.logger.debug('Retrying connection...')
@@ -1194,7 +1194,7 @@ class Restore(BaseRestore):
 
         if self._ignore_fdr:
             self.logger.info('Establishing a mock FDR listener')
-            self._fdr = ServiceConnection.create(self._restored.udid, FDRClient.SERVICE_PORT)
+            self._fdr = ServiceConnection.create_using_usbmux(self._restored.udid, FDRClient.SERVICE_PORT)
         else:
             self.logger.info('Starting FDR listener thread')
             start_fdr_thread(fdr_type.FDR_CTRL)
